======================
Global Logger
======================


.. image:: https://img.shields.io/pypi/v/global_logger.svg
        :target: https://pypi.python.org/pypi/global_logger

..
  .. image:: https://readthedocs.org/projects/global-logger/badge/?version=latest
          :target: https://global-logger.readthedocs.io/en/latest/?badge=latest
          :alt: Documentation Status

.. image:: https://github.com/ALERTua/global_logger/workflows/Python%20Package/badge.svg?branch=master
        :target: https://github.com/ALERTua/global_logger/actions?query=workflow%3A%22Python+Package%22




Global Logger

Based on Python built-in logger, expands it, and provides a global logger to your system.

* Free software: MIT license
* Documentation:
    * https://alertua.github.io/global_logger
    * https://global-logger.readthedocs.io / https://global-logger.rtfd.io
* PyPi modules: https://pypi.org/project/global-logger

Features
--------

* Easy on-screen logging setup without pain for Python newcomers
* Easy .log files output setup without pain for Python newcomers
* Python 2 and 3 compatible
